@@ -22,7 +22,7 @@ class Conversation:
     def __init__(
         self,
         recording: Path,
-        num_speakers: int = 2,
+        num_speakers: int = 0,
         reload: bool = True,
         speaker_mapping: Optional[Dict[str, str]] = None,
         meeting_datetime: Optional[datetime] = None,
@@ -39,7 +39,7 @@ class Conversation:
         recording : pathlib.Path
             Path to the conversation recording.
         num_speakers : int
-            The number of speakers in the conversation.
+            The number of speakers in the conversation, defaulting to 0 if unknown.
         reload : bool
             If True, try to load an existing saved conversation with the default filename.
             If False, create a new Conversation instance.
@@ -90,13 +90,13 @@ class Conversation:
                 print(f"- {attendee}")
 
         # Set num_speakers based on attendees if not provided
-        if num_speakers is None and attendees is not None:
+        if num_speakers == 0 and attendees is not None:
             self._num_speakers = len(attendees)
         else:
             self._num_speakers = num_speakers
 
         # Verify that num_speakers is equal to the number of attendees
-        if num_speakers is not None and attendees is not None:
+        if num_speakers > 0 and attendees is not None:
             if num_speakers != len(attendees):
                 raise ValueError(
                     "The number of speakers must match the number of attendees."
@@ -107,19 +107,91 @@ class Conversation:
         created_timestamp = os.path.getmtime(file_path)
         return datetime.fromtimestamp(created_timestamp, timezone.utc)
 
-    def transcribe(self, method: str = "whisper", model: str = "medium.en"):
-        """Transcribe a conversation."""
-        from .transcribe import whisper
+    def transcribe(
+        self,
+        method: str = "assembly",
+        model: str = "nano",
+        prompt: str | None = " - How are you? - I'm fine, thank you.",
+        language: str = "en",
+    ):
+        """
+        Transcribe a conversation using the specified method and model.
 
+        Parameters
+        ----------
+        method : str, optional
+            The transcription method to use, defaults to "assembly".
+            Can be one of whisper or assembly.
+        model : str, optional
+            The model to be used for transcription, must be one of tiny, base, small, large,
+            medium, tiny.en, base.en, small.en, medium.en, and openai.en, best, nano.
+            Defaults to "nano".
+        prompt : str, None, optional
+            An optional prompt to be used for transcription, defaults to None.
+        language : str, optional
+            The language of the conversation, defaults to "en".
+
+        Returns
+        -------
+        None
+
+        Raises
+        ------
+        RuntimeError
+            If the conversation has already been transcribed.
+        ValueError
+            If an invalid model name is provided.
+        NotImplementedError
+            If the method is not supported.
+        """
         if self._transcription is not None:
-            print(
-                "The conversation has already been transcribed. Skipping transcription."
-            )
-            return
+            raise RuntimeError("The conversation has already been transcribed.")
 
-        self._transcription = whisper.process(
-            audio_file=self._recording, model_name=model
-        )
+        available_models = [
+            "tiny",
+            "base",
+            "small",
+            "large",
+            "medium",
+            "tiny.en",
+            "base.en",
+            "small.en",
+            "medium.en",
+            "openai.en",
+            "nano",
+            "best",
+        ]
+        if model not in available_models:
+            raise ValueError(
+                f"Invalid model '{model}'. Must be one of {available_models}."
+            )
+
+        if method == "whisper":
+            from .transcribe import whisper
+
+            self._transcription = whisper.process(
+                audio_file=self._recording,
+                model_name=model,
+                prompt=prompt,
+                language=language,
+            )
+        elif method == "assembly":
+            from .transcribe import assembly
+
+            self._transcription = assembly.process(
+                audio_file=self._recording, model_name=model, language=language
+            )
+
+            # by default, we use assembly to diarise the conversation too
+            self._diarisation = [
+                {
+                    "note": "diairisation performed by assembly and transcript contains speaker labels"
+                }
+            ]
+        else:
+            raise NotImplementedError(
+                f"Transcription method '{method}' is not supported."
+            )
 
     def diarise(self, method: str = "simple"):
         """Diarise a conversation."""
@@ -253,13 +325,23 @@ class Conversation:
             print(answer)
         return answer
 
-    def shortened_transcript(self) -> str:
+    def shortened_transcript(
+        self, chunk_num_tokens: int = 128000, shorten_iterations: int = 2
+    ) -> str:
         """
         Get the shortened transcript of the conversation.
 
         This method returns the previously shortened transcript if available.
         If not, it computes the shortened transcript first and then returns it.
 
+        Parameters
+        ----------
+        chunk_num_tokens : int
+            The number of tokens to use for each chunk.
+            The default is 7372, which is 90% of the 8k model limit.
+        shorten_iterations : int
+            The number of iterations to use when shortening the transcript.
+
         Returns
         -------
         str
@@ -268,7 +350,9 @@ class Conversation:
         if self._transcription_shortened is None:
             from .ai._shorten_transcript import _shorten_transcript
 
-            self._transcription_shortened = _shorten_transcript(self.export_text())
+            self._transcription_shortened = _shorten_transcript(
+                self.export_text(), chunk_num_tokens, shorten_iterations
+            )
 
         return self._transcription_shortened
 
